pub enum Step {
Done(Result<Value, String>),
Wait(Promise, Box<dyn FnOnce(PromiseState) -> Step>),
Yield(Value, Box<dyn FnOnce(Value) -> Step>),
Continue(Box<dyn FnOnce() -> Step>),
}Variants
Done(Result<Value, String>)
Wait(Promise, Box<dyn FnOnce(PromiseState) -> Step>)
Yield(Value, Box<dyn FnOnce(Value) -> Step>)
Continue(Box<dyn FnOnce() -> Step>)
Defers the next synchronous continuation to the fiber driver. Without this trampoline, a document with many top-level forms keeps one Rust stack frame per completed form (and can exhaust the smaller WASM stack).