pub fn with_protocols<R>(
registry: &ProtocolRegistry,
operation: impl FnOnce() -> R,
) -> RExpand description
Runs an evaluation with a registry available to protocol dispatch.
pub fn with_protocols<R>(
registry: &ProtocolRegistry,
operation: impl FnOnce() -> R,
) -> RRuns an evaluation with a registry available to protocol dispatch.