pub struct MemoryRemoteClient { /* private fields */ }Expand description
A deterministic in-memory client useful for host integration tests and browser adapters that have not yet bound a real transport.
Implementations
Sourceimpl MemoryRemoteClient
impl MemoryRemoteClient
pub fn new() -> Self
pub fn with_capabilities(capabilities: FilesystemCapabilities) -> Self
pub fn unauthenticated(self) -> Self
pub fn with_unverified_host_key(self) -> Self
pub fn insert(&self, path: &str, bytes: Vec<u8>) -> Result<(), FileError>
pub fn provider(&self) -> &MemoryFileProvider