pub struct DispatchReport {
pub callbacks: Vec<DeliveredEvent>,
pub queued: usize,
pub dropped: usize,
}Fields
callbacks: Vec<DeliveredEvent>Callback delivery is returned to the trusted native caller. The hub never executes arbitrary guest code on the application thread.
queued: usizedropped: usizeTrait Implementations
Sourceimpl Clone for DispatchReport
impl Clone for DispatchReport
Sourcefn clone(&self) -> DispatchReport
fn clone(&self) -> DispatchReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DispatchReport
impl Debug for DispatchReport
Sourceimpl Default for DispatchReport
impl Default for DispatchReport
Sourcefn default() -> DispatchReport
fn default() -> DispatchReport
Returns the “default value” for a type. Read more
impl Eq for DispatchReport
Sourceimpl PartialEq for DispatchReport
impl PartialEq for DispatchReport
impl StructuralPartialEq for DispatchReport