Module native

Module native 

Optional machine-code backend. Trace IR is lowered to a tiny wasm module and Wasmtime/Cranelift compiles that module to host code. This reuses the runtime’s existing native Cranelift dependency and adds nothing to wasm or default builds.

Structs

NativeBackend
NativeTrace