pub struct JitTelemetry {Show 15 fields
pub backedges: u64,
pub compile_attempts: u64,
pub compiled: u64,
pub rejected: u64,
pub entries: u64,
pub completed_iterations: u64,
pub side_exits: u64,
pub recording_starts: u64,
pub recording_completed: u64,
pub recording_aborts: u64,
pub trace_paths: u64,
pub branch_exits: u64,
pub type_exits: u64,
pub error_exits: u64,
pub disabled_loops: u64,
}Expand description
Per-program tracing-JIT counters. They make it possible to distinguish a cold loop, an unsupported trace, and a trace that is compiled but exits.
Fields
backedges: u64compile_attempts: u64compiled: u64rejected: u64entries: u64completed_iterations: u64side_exits: u64recording_starts: u64recording_completed: u64recording_aborts: u64trace_paths: u64branch_exits: u64type_exits: u64error_exits: u64disabled_loops: u64Trait Implementations
Sourceimpl Clone for JitTelemetry
impl Clone for JitTelemetry
Sourcefn clone(&self) -> JitTelemetry
fn clone(&self) -> JitTelemetry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for JitTelemetry
Sourceimpl Debug for JitTelemetry
impl Debug for JitTelemetry
Sourceimpl Default for JitTelemetry
impl Default for JitTelemetry
Sourcefn default() -> JitTelemetry
fn default() -> JitTelemetry
Returns the “default value” for a type. Read more
impl Eq for JitTelemetry
Sourceimpl PartialEq for JitTelemetry
impl PartialEq for JitTelemetry
impl StructuralPartialEq for JitTelemetry