NamespaceRegistry

Struct NamespaceRegistry 

pub struct NamespaceRegistry<V> { /* private fields */ }

Implementations

Source

impl<V: Clone> NamespaceRegistry<V>

pub fn new(initial: impl AsRef<str>) -> Self

pub fn current(&self) -> Namespace<V>

pub fn find(&self, name: impl AsRef<str>) -> Option<Namespace<V>>

pub fn find_or_create(&self, name: impl AsRef<str>) -> Namespace<V>

pub fn set_current(&self, name: impl AsRef<str>) -> Namespace<V>

pub fn all(&self) -> Vec<Namespace<V>>

pub fn known_names(&self) -> Vec<Symbol>

Returns every namespace known either as a materialized namespace or as a discoverable module with load state. Catalog-backed modules can therefore be inspected before a Namespace value exists.

pub fn load_state(&self, name: impl AsRef<str>) -> Option<NamespaceLoadState>

pub fn set_load_state(&self, name: impl AsRef<str>, state: NamespaceLoadState)

pub fn clear_load_state(&self, name: impl AsRef<str>)

pub fn load_failure(&self, name: impl AsRef<str>) -> Option<String>

pub fn set_load_failure(&self, name: impl AsRef<str>, detail: impl Into<String>)

pub fn clear_load_failure(&self, name: impl AsRef<str>)

pub fn register_global_alias( &self, alias: impl AsRef<str>, namespace: impl AsRef<str>, ) -> Result<(), String>

pub fn global_aliases(&self) -> Vec<(Symbol, Symbol)>

pub fn register_global_import( &self, shorthand: impl AsRef<str>, canonical: impl AsRef<str>, ) -> Result<(), String>

pub fn global_imports(&self) -> Vec<(Symbol, Symbol)>

pub fn module_revision(&self, name: impl AsRef<str>) -> u64

pub fn commit_module_revision(&self, name: impl AsRef<str>) -> u64

pub fn module_dependencies(&self, name: impl AsRef<str>) -> Vec<Symbol>

pub fn clear_module_dependencies(&self, name: impl AsRef<str>)

pub fn record_module_dependency( &self, module: impl AsRef<str>, dependency: impl AsRef<str>, )

pub fn snapshot(&self) -> NamespaceRegistrySnapshot<V>
where V: 'static,

pub fn transaction_snapshot<'a>( &self, names: impl IntoIterator<Item = &'a str>, ) -> NamespaceTransactionSnapshot<V>
where V: 'static,

pub fn restore(&self, snapshot: NamespaceRegistrySnapshot<V>)
where V: 'static,

pub fn restore_transaction(&self, snapshot: NamespaceTransactionSnapshot<V>)
where V: 'static,

pub fn remove(&self, name: impl AsRef<str>) -> Option<Namespace<V>>

pub fn resolve(&self, symbol: &Symbol) -> Option<Var<V>>
where V: Clone,

pub fn set_var(&self, symbol: Symbol, var: Var<V>) -> Result<Var<V>, String>
where V: Clone,

pub fn visible_symbol_names(&self) -> Vec<String>