pub fn package_namespaces(
package: &PackageDefinition,
available: &[String],
) -> Vec<String>Expand description
Returns the exact namespace ownership implied by one semantic package.
pub fn package_namespaces(
package: &PackageDefinition,
available: &[String],
) -> Vec<String>Returns the exact namespace ownership implied by one semantic package.