source_resources

Function source_resources 

pub fn source_resources(
    project: &Project,
) -> Result<Vec<(String, String)>, String>
Returns namespace resources from installed dependencies followed by the automatically selected native Rust profile of the consuming project.