sync_lock

Function sync_lock 

pub fn sync_lock(project: &Project, mode: LockMode) -> Result<PathBuf, String>
Creates or validates the lockfile for graphs that need no remote packages. Remote graphs deliberately stop here until the reviewed registry and identity clients can provide the required signed release metadata.