pub struct Distribution {
pub launcher: String,
pub entry: String,
}Fields
launcher: StringBasename for the copied host executable, without a platform extension.
entry: StringHAL entry Var that receives the complete argv vector.