Module resp

Module resp 

RESP listener and wire codec for the native runtime broker. Wire format, dialects, and operation semantics are specified in specs/01-lang/007-resp/draft/hal-resp-protocol.md.

Structs

RespConnection
RespServer

Enums

RespValue