pub struct Session { /* private fields */ }Expand description
An isolated, named execution context owned by a SessionKernel.
Implementations
Sourceimpl Session
impl Session
pub fn spec(&self) -> &SessionSpec
pub fn id(&self) -> &SessionId
pub fn name(&self) -> &str
pub fn state(&self) -> SessionState
pub fn filesystem_mount(&self) -> Option<SessionMountId>
pub fn eval(&mut self, source: &str) -> Result<String, String>
pub fn current_namespace(&self) -> String
pub fn native_execution_telemetry( &self, ) -> Result<NativeExecutionTelemetry, String>
pub fn install_native_socket_provider(&mut self)
pub fn install_native_process_provider(&mut self)
Sourceimpl Session
impl Session
Sourcepub fn register_live_session(
&mut self,
live_session: Box<dyn LiveSession>,
) -> Result<LiveSessionState, LiveSessionError>
pub fn register_live_session( &mut self, live_session: Box<dyn LiveSession>, ) -> Result<LiveSessionState, LiveSessionError>
Transfers one backend-neutral live session into this Session’s private lifecycle. Live-session identities cannot be reused, including after a nested session has been cancelled or disposed.
Sourcepub fn start_interpreter_live_session(
&mut self,
live_session_id: impl Into<String>,
source: LiveSource,
) -> Result<LiveSessionState, LiveSessionError>
pub fn start_interpreter_live_session( &mut self, live_session_id: impl Into<String>, source: LiveSource, ) -> Result<LiveSessionState, LiveSessionError>
Starts the authoritative interpreter target as a built-in controlling instrument over this Session’s Runtime-owned instrumentation hub.
pub fn live_session_ids(&self) -> Vec<String>
pub fn live_session_count(&self) -> usize
pub fn live_session_state( &self, live_session_id: &str, ) -> Result<LiveSessionState, LiveSessionError>
pub fn live_session_capabilities( &self, live_session_id: &str, ) -> Result<LiveSessionCapabilities, LiveSessionError>
Sourcepub fn dispatch_live_session(
&mut self,
request: LiveSessionRequest,
) -> Result<LiveSessionReply, LiveSessionError>
pub fn dispatch_live_session( &mut self, request: LiveSessionRequest, ) -> Result<LiveSessionReply, LiveSessionError>
Dispatches one fenced command to a live session owned by this Session. The request is never routed through Sandbox and backend objects never leave the owning Session.