pub fn current_work_context() -> Option<WorkContext>Expand description
Return the currently executing cooperative work context, if any.
pub fn current_work_context() -> Option<WorkContext>Return the currently executing cooperative work context, if any.