Module plan

Module plan 

Portable, closure-free work-plan execution.

A WorkPlan is data that can cross a Hara package boundary. Leaf behavior is referenced by a stable target name and supplied by a local WorkRegistry; closures are intentionally never part of the encoded plan. The implementation is single-threaded because guest Values are evaluator-thread values, just like super::WorkHost.

Structs

WorkPlan
A canonical v1 plan backed by a Hara portable value.
WorkRegistry
Process-local bindings for the otherwise portable target names in a plan.
WorkRuntime
Evaluates plans against explicit targets and an optional suspension bridge.

Enums

WorkOperation
The operations accepted by the portable work-plan v1 envelope.

Functions

target_name

Type Aliases

SuspensionTarget
WorkTarget
A named local implementation for a serializable work target.