pub struct WorkRun { /* private fields */ }Expand description
Live process-owned handle returned immediately from submission.
Implementations
Sourceimpl WorkRun
impl WorkRun
pub fn work_id(&self) -> WorkId
pub fn work_status(&self) -> WorkRunStatus
pub fn deadline(&self) -> Option<Instant>
pub fn cancellation_token(&self) -> WorkCancellationToken
Sourcepub fn work_result(&self) -> Promise
pub fn work_result(&self) -> Promise
Return the same native result Promise on every call.
pub fn work_cancel(&self, reason: Value) -> Promise
pub fn work_events(&self, after: usize) -> Value
Sourcepub fn emit(&self, kind: Value, data: Value) -> bool
pub fn emit(&self, kind: Value, data: Value) -> bool
Append one ordered domain event to this live run.
pub fn cancel(&self, reason: Value) -> bool
pub fn closed(&self) -> bool
pub fn same_identity(&self, other: &Self) -> bool