pub fn source_resources(
project: &Project,
) -> Result<Vec<(String, String)>, String>Expand description
Returns namespace resources from installed dependencies followed by the automatically selected native Rust profile of the consuming project.