pub fn sync_lock(project: &Project, mode: LockMode) -> Result<PathBuf, String>Expand description
Creates or validates the lockfile for graphs that need no remote packages. Remote graphs deliberately stop here until the reviewed registry and identity clients can provide the required signed release metadata.