Structs
- Work
Cancellation Token - Cooperative cancellation token exposed through the active work context.
- Work
Context - Opaque evaluator-thread context for one native work scope.
- Work
Host - Cloneable process-owned host for live work handles.
- Work
Host Status - Process-host lifecycle metadata.
- WorkId
- Validated portable identifier for one native work run.
- Work
Options - Submission-time scope and deadline options.
- WorkRun
- Live process-owned handle returned immediately from submission.
- Work
RunStatus - Non-blocking status snapshot for a live work run.
Enums
- Work
RunState - Monotonic state of a live native work run.
Functions
- current_
work_ context - Return the currently executing cooperative work context, if any.
- monotonic_
nanos - process_
work_ host - Return the process/evaluator-thread host shared by independent sessions.